@@ -5,7 +5,8 @@ from asgiref.sync import async_to_sync
 
 from django.contrib.admindocs.middleware import XViewMiddleware
 from django.contrib.auth.middleware import (
-    AuthenticationMiddleware, RemoteUserMiddleware,
+    AuthenticationMiddleware,
+    RemoteUserMiddleware,
 )
 from django.contrib.flatpages.middleware import FlatpageFallbackMiddleware
 from django.contrib.messages.middleware import MessageMiddleware
@@ -16,12 +17,12 @@ from django.db import connection
 from django.http.request import HttpRequest
 from django.http.response import HttpResponse
 from django.middleware.cache import (
-    CacheMiddleware, FetchFromCacheMiddleware, UpdateCacheMiddleware,
+    CacheMiddleware,
+    FetchFromCacheMiddleware,
+    UpdateCacheMiddleware,
 )
 from django.middleware.clickjacking import XFrameOptionsMiddleware
-from django.middleware.common import (
-    BrokenLinkEmailsMiddleware, CommonMiddleware,
-)
+from django.middleware.common import BrokenLinkEmailsMiddleware, CommonMiddleware
 from django.middleware.csrf import CsrfViewMiddleware
 from django.middleware.gzip import GZipMiddleware
 from django.middleware.http import ConditionalGetMiddleware
@@ -64,25 +65,25 @@ class MiddlewareMixinTests(SimpleTestCase):
 
         self.assertEqual(
             repr(MiddlewareMixin(GetResponse())),
-            '<MiddlewareMixin get_response=GetResponse>',
+            "<MiddlewareMixin get_response=GetResponse>",
         )
         self.assertEqual(
             repr(MiddlewareMixin(get_response)),
-            '<MiddlewareMixin get_response='
-            'MiddlewareMixinTests.test_repr.<locals>.get_response>',
+            "<MiddlewareMixin get_response="
+            "MiddlewareMixinTests.test_repr.<locals>.get_response>",
         )
         self.assertEqual(
             repr(CsrfViewMiddleware(GetResponse())),
-            '<CsrfViewMiddleware get_response=GetResponse>',
+            "<CsrfViewMiddleware get_response=GetResponse>",
         )
         self.assertEqual(
             repr(CsrfViewMiddleware(get_response)),
-            '<CsrfViewMiddleware get_response='
-            'MiddlewareMixinTests.test_repr.<locals>.get_response>',
+            "<CsrfViewMiddleware get_response="
+            "MiddlewareMixinTests.test_repr.<locals>.get_response>",
         )
 
     def test_passing_explicit_none(self):
-        msg = 'get_response must be provided.'
+        msg = "get_response must be provided."
         for middleware in self.middlewares:
             with self.subTest(middleware=middleware):
                 with self.assertRaisesMessage(ValueError, msg):
@@ -112,6 +113,7 @@ class MiddlewareMixinTests(SimpleTestCase):
         the sync_to_async thread_sensitive flag enabled, so that database
         operations use the correct thread and connection.
         """
+
         def request_lifecycle():
             """Fake request_started/request_finished."""
             return (threading.get_ident(), id(connection))
