@@ -17,7 +17,8 @@ from django.forms.formsets import BaseFormSet, all_valid, formset_factory
 from django.forms.utils import ErrorList
 from django.forms.widgets import HiddenInput
 from django.test import SimpleTestCase
-from tests.forms_tests.tests import jinja2_tests
+
+from . import jinja2_tests
 
 
 class Choice(Form):
@@ -226,10 +227,11 @@ class FormsFormsetTestCase(SimpleTestCase):
         )
         self.assertHTMLEqual(
             "\n".join(form.as_ul() for form in formset.forms),
-            """<li>Choice: <input type="text" name="choices-0-choice" value="Calexico"></li>
-<li>Votes: <input type="number" name="choices-0-votes" value="100"></li>
-<li>Choice: <input type="text" name="choices-1-choice"></li>
-<li>Votes: <input type="number" name="choices-1-votes"></li>""",
+            '<li>Choice: <input type="text" name="choices-0-choice" value="Calexico">'
+            "</li>"
+            '<li>Votes: <input type="number" name="choices-0-votes" value="100"></li>'
+            '<li>Choice: <input type="text" name="choices-1-choice"></li>'
+            '<li>Votes: <input type="number" name="choices-1-votes"></li>',
         )
 
     def test_blank_form_unfilled(self):
@@ -483,14 +485,15 @@ class FormsFormsetTestCase(SimpleTestCase):
         formset = ChoiceFormSet(initial=initial, auto_id=False, prefix="choices")
         self.assertHTMLEqual(
             "\n".join(form.as_ul() for form in formset.forms),
-            """<li>Choice: <input type="text" name="choices-0-choice" value="Calexico"></li>
-<li>Votes: <input type="number" name="choices-0-votes" value="100"></li>
-<li>Choice: <input type="text" name="choices-1-choice"></li>
-<li>Votes: <input type="number" name="choices-1-votes"></li>
-<li>Choice: <input type="text" name="choices-2-choice"></li>
-<li>Votes: <input type="number" name="choices-2-votes"></li>
-<li>Choice: <input type="text" name="choices-3-choice"></li>
-<li>Votes: <input type="number" name="choices-3-votes"></li>""",
+            '<li>Choice: <input type="text" name="choices-0-choice" value="Calexico">'
+            "</li>"
+            '<li>Votes: <input type="number" name="choices-0-votes" value="100"></li>'
+            '<li>Choice: <input type="text" name="choices-1-choice"></li>'
+            '<li>Votes: <input type="number" name="choices-1-votes"></li>'
+            '<li>Choice: <input type="text" name="choices-2-choice"></li>'
+            '<li>Votes: <input type="number" name="choices-2-votes"></li>'
+            '<li>Choice: <input type="text" name="choices-3-choice"></li>'
+            '<li>Votes: <input type="number" name="choices-3-votes"></li>',
         )
         # Retrieving an empty form works. Tt shows up in the form list.
         self.assertTrue(formset.empty_form.empty_permitted)
@@ -514,15 +517,17 @@ class FormsFormsetTestCase(SimpleTestCase):
         formset = ChoiceFormSet(initial=initial, auto_id=False, prefix="choices")
         self.assertHTMLEqual(
             "\n".join(form.as_ul() for form in formset.forms),
-            """<li>Choice: <input type="text" name="choices-0-choice" value="Calexico"></li>
-<li>Votes: <input type="number" name="choices-0-votes" value="100"></li>
-<li>Delete: <input type="checkbox" name="choices-0-DELETE"></li>
-<li>Choice: <input type="text" name="choices-1-choice" value="Fergie"></li>
-<li>Votes: <input type="number" name="choices-1-votes" value="900"></li>
-<li>Delete: <input type="checkbox" name="choices-1-DELETE"></li>
-<li>Choice: <input type="text" name="choices-2-choice"></li>
-<li>Votes: <input type="number" name="choices-2-votes"></li>
-<li>Delete: <input type="checkbox" name="choices-2-DELETE"></li>""",
+            '<li>Choice: <input type="text" name="choices-0-choice" value="Calexico">'
+            "</li>"
+            '<li>Votes: <input type="number" name="choices-0-votes" value="100"></li>'
+            '<li>Delete: <input type="checkbox" name="choices-0-DELETE"></li>'
+            '<li>Choice: <input type="text" name="choices-1-choice" value="Fergie">'
+            "</li>"
+            '<li>Votes: <input type="number" name="choices-1-votes" value="900"></li>'
+            '<li>Delete: <input type="checkbox" name="choices-1-DELETE"></li>'
+            '<li>Choice: <input type="text" name="choices-2-choice"></li>'
+            '<li>Votes: <input type="number" name="choices-2-votes"></li>'
+            '<li>Delete: <input type="checkbox" name="choices-2-DELETE"></li>',
         )
         # To delete something, set that form's special delete field to 'on'.
         # Let's go ahead and delete Fergie.
@@ -657,15 +662,17 @@ class FormsFormsetTestCase(SimpleTestCase):
         formset = ChoiceFormSet(initial=initial, auto_id=False, prefix="choices")
         self.assertHTMLEqual(
             "\n".join(form.as_ul() for form in formset.forms),
-            """<li>Choice: <input type="text" name="choices-0-choice" value="Calexico"></li>
-<li>Votes: <input type="number" name="choices-0-votes" value="100"></li>
-<li>Order: <input type="number" name="choices-0-ORDER" value="1"></li>
-<li>Choice: <input type="text" name="choices-1-choice" value="Fergie"></li>
-<li>Votes: <input type="number" name="choices-1-votes" value="900"></li>
-<li>Order: <input type="number" name="choices-1-ORDER" value="2"></li>
-<li>Choice: <input type="text" name="choices-2-choice"></li>
-<li>Votes: <input type="number" name="choices-2-votes"></li>
-<li>Order: <input type="number" name="choices-2-ORDER"></li>""",
+            '<li>Choice: <input type="text" name="choices-0-choice" value="Calexico">'
+            "</li>"
+            '<li>Votes: <input type="number" name="choices-0-votes" value="100"></li>'
+            '<li>Order: <input type="number" name="choices-0-ORDER" value="1"></li>'
+            '<li>Choice: <input type="text" name="choices-1-choice" value="Fergie">'
+            "</li>"
+            '<li>Votes: <input type="number" name="choices-1-votes" value="900"></li>'
+            '<li>Order: <input type="number" name="choices-1-ORDER" value="2"></li>'
+            '<li>Choice: <input type="text" name="choices-2-choice"></li>'
+            '<li>Votes: <input type="number" name="choices-2-votes"></li>'
+            '<li>Order: <input type="number" name="choices-2-ORDER"></li>',
         )
         data = {
             "choices-TOTAL_FORMS": "3",  # the number of forms rendered
@@ -783,22 +790,25 @@ class FormsFormsetTestCase(SimpleTestCase):
         formset = ChoiceFormSet(initial=initial, auto_id=False, prefix="choices")
         self.assertHTMLEqual(
             "\n".join(form.as_ul() for form in formset.forms),
-            """<li>Choice: <input type="text" name="choices-0-choice" value="Calexico"></li>
-<li>Votes: <input type="number" name="choices-0-votes" value="100"></li>
-<li>Order: <input type="number" name="choices-0-ORDER" value="1"></li>
-<li>Delete: <input type="checkbox" name="choices-0-DELETE"></li>
-<li>Choice: <input type="text" name="choices-1-choice" value="Fergie"></li>
-<li>Votes: <input type="number" name="choices-1-votes" value="900"></li>
-<li>Order: <input type="number" name="choices-1-ORDER" value="2"></li>
-<li>Delete: <input type="checkbox" name="choices-1-DELETE"></li>
-<li>Choice: <input type="text" name="choices-2-choice" value="The Decemberists"></li>
-<li>Votes: <input type="number" name="choices-2-votes" value="500"></li>
-<li>Order: <input type="number" name="choices-2-ORDER" value="3"></li>
-<li>Delete: <input type="checkbox" name="choices-2-DELETE"></li>
-<li>Choice: <input type="text" name="choices-3-choice"></li>
-<li>Votes: <input type="number" name="choices-3-votes"></li>
-<li>Order: <input type="number" name="choices-3-ORDER"></li>
-<li>Delete: <input type="checkbox" name="choices-3-DELETE"></li>""",
+            '<li>Choice: <input type="text" name="choices-0-choice" value="Calexico">'
+            "</li>"
+            '<li>Votes: <input type="number" name="choices-0-votes" value="100"></li>'
+            '<li>Order: <input type="number" name="choices-0-ORDER" value="1"></li>'
+            '<li>Delete: <input type="checkbox" name="choices-0-DELETE"></li>'
+            '<li>Choice: <input type="text" name="choices-1-choice" value="Fergie">'
+            "</li>"
+            '<li>Votes: <input type="number" name="choices-1-votes" value="900"></li>'
+            '<li>Order: <input type="number" name="choices-1-ORDER" value="2"></li>'
+            '<li>Delete: <input type="checkbox" name="choices-1-DELETE"></li>'
+            '<li>Choice: <input type="text" name="choices-2-choice" '
+            'value="The Decemberists"></li>'
+            '<li>Votes: <input type="number" name="choices-2-votes" value="500"></li>'
+            '<li>Order: <input type="number" name="choices-2-ORDER" value="3"></li>'
+            '<li>Delete: <input type="checkbox" name="choices-2-DELETE"></li>'
+            '<li>Choice: <input type="text" name="choices-3-choice"></li>'
+            '<li>Votes: <input type="number" name="choices-3-votes"></li>'
+            '<li>Order: <input type="number" name="choices-3-ORDER"></li>'
+            '<li>Delete: <input type="checkbox" name="choices-3-DELETE"></li>',
         )
         # Let's delete Fergie, and put The Decemberists ahead of Calexico.
         data = {
