@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.db import migrations, models
 
 
@@ -27,12 +24,12 @@ class Migration(migrations.Migration):
             ],
         ),
         migrations.AddField(
-            model_name='tribble',
-            name='bool',
+            model_name="tribble",
+            name="bool",
             field=models.BooleanField(default=False),
         ),
         migrations.AlterUniqueTogether(
-            name='author',
-            unique_together=set([('name', 'slug')]),
+            name="author",
+            unique_together={("name", "slug")},
         ),
     ]
